==> openlit-1.33.0-py3-none-any.whl: openlit/instrumentation/controlflow/__init__.py <==
# pylint: disable=useless-return, bad-staticmethod-argument, disable=duplicate-code
"""Initializer of Auto Instrumentation of controlflow Functions"""

from typing import Collection
import importlib.metadata
from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
from wrapt import wrap_function_wrapper

from openlit.instrumentation.controlflow.controlflow import (
    wrap_controlflow
)

_instruments = ("controlflow >= 0.3.2",)

class ControlFlowInstrumentor(BaseInstrumentor):
    """
    An instrumentor for controlflow's client library.
    """

    def instrumentation_dependencies(self) -> Collection[str]:
        return _instruments

    def _instrument(self, **kwargs):
        application_name = kwargs.get("application_name", "default_application")
        environment = kwargs.get("environment", "default_environment")
        tracer = kwargs.get("tracer")
        metrics = kwargs.get("metrics_dict")
        pricing_info = kwargs.get("pricing_info", {})
        trace_content = kwargs.get("trace_content", False)
        disable_metrics = kwargs.get("disable_metrics")
        version = importlib.metadata.version("controlflow")

        wrap_function_wrapper(
            "controlflow.agents.agent",
            "Agent.__init__",
            wrap_controlflow("controlflow.create_agent", version, environment, application_name,
                  tracer, pricing_info, trace_content, metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "controlflow.tasks.task",
            "Task.__init__",
            wrap_controlflow("controlflow.create_task", version, environment, application_name,
                  tracer, pricing_info, trace_content, metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "controlflow",
            "run",
            wrap_controlflow("controlflow.run", version, environment, application_name,
                  tracer, pricing_info, trace_content, metrics, disable_metrics),
        )

    def _uninstrument(self, **kwargs):
        # Proper uninstrumentation logic to revert patched methods
        pass

==> openlit-1.34.12-py3-none-any.whl: openlit/instrumentation/controlflow/__init__.py <==
# pylint: disable=useless-return, bad-staticmethod-argument, disable=duplicate-code
"""Initializer of Auto Instrumentation of controlflow Functions"""

from typing import Collection
import importlib.metadata
from opentelemetry.instrumentation.instrumentor import BaseInstrumentor
from wrapt import wrap_function_wrapper

from openlit.instrumentation.controlflow.controlflow import (
    wrap_controlflow
)

_instruments = ("controlflow >= 0.3.2",)

class ControlFlowInstrumentor(BaseInstrumentor):
    """
    An instrumentor for controlflow's client library.
    """

    def instrumentation_dependencies(self) -> Collection[str]:
        return _instruments

    def _instrument(self, **kwargs):
        application_name = kwargs.get("application_name", "default_application")
        environment = kwargs.get("environment", "default_environment")
        tracer = kwargs.get("tracer")
        metrics = kwargs.get("metrics_dict")
        pricing_info = kwargs.get("pricing_info", {})
        capture_message_content = kwargs.get("capture_message_content", False)
        disable_metrics = kwargs.get("disable_metrics")
        version = importlib.metadata.version("controlflow")

        wrap_function_wrapper(
            "controlflow.agents.agent",
            "Agent.__init__",
            wrap_controlflow("controlflow.create_agent", version, environment, application_name,
                  tracer, pricing_info, capture_message_content, metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "controlflow.tasks.task",
            "Task.__init__",
            wrap_controlflow("controlflow.create_task", version, environment, application_name,
                  tracer, pricing_info, capture_message_content, metrics, disable_metrics),
        )

        wrap_function_wrapper(
            "controlflow",
            "run",
            wrap_controlflow("controlflow.run", version, environment, application_name,
                  tracer, pricing_info, capture_message_content, metrics, disable_metrics),
        )

    def _uninstrument(self, **kwargs):
        # Proper uninstrumentation logic to revert patched methods
        pass
